"""victoria

This is the core functionality of Victoria. It contains functionality common
to all of Victoria such as Config and plugin loading.

Author
    Sam Gibson <sgibson@glasswallsolutions.com>
"""